.. _recipe_asr.borncharges:

asr.borncharges
===============


.. contents:: Contents
   :local:

Summary
-------

This is the documentation for :py:mod:`asr.borncharges`-recipe.
This recipe is comprised of a single step, namely:

  - :py:func:`asr.borncharges.main`

Run this recipe through the CLI interface

.. code-block:: console

   $ asr run asr.borncharges

or as a python module

.. code-block:: console

   $ python -m asr.borncharges

Detailed description
--------------------
Effective Born charges.

Steps
-----


asr.borncharges
^^^^^^^^^^^^^^^
.. autofunction:: asr.borncharges.main
   